@@ -76,6 +76,8 @@ _RELEASES = {
     'V': 'Victoria',
     'W': 'Wallaby',
     'X': 'Xena',
+    'Y': 'Yoga',
+    'Z': 'Zed',
 }
 
 
@@ -157,6 +159,8 @@ class deprecated(object):
     VICTORIA = 'V'
     WALLABY = 'W'
     XENA = 'X'
+    YOGA = 'Y'
+    ZED = 'Z'
 
     def __init__(self, as_of, in_favor_of=None, remove_in=2, what=None):
         """Initialize decorator
